@@ -2,7 +2,7 @@
  *
  * redland.h - Redland RDF Application Framework main header
  *
- * $Id: librdf.h,v 1.27 2002/05/28 22:02:58 cmdjb Exp $
+ * $Id: librdf.h,v 1.30 2002/12/09 15:13:30 cmdjb Exp $
  *
  * Copyright (C) 2000-2001 David Beckett - http://purl.org/net/dajobe/
  * Institute for Learning and Research Technology - http://www.ilrt.org/
@@ -39,7 +39,7 @@ typedef struct librdf_uri_s librdf_uri;
 typedef struct librdf_list_s librdf_list;
 typedef struct librdf_iterator_s librdf_iterator;
 typedef struct librdf_node_s librdf_node;
-typedef struct librdf_node_s librdf_statement;
+typedef struct librdf_statement_s librdf_statement;
 typedef struct librdf_model_s librdf_model;
 typedef struct librdf_storage_s librdf_storage;
 typedef struct librdf_storage_factory_s librdf_storage_factory;
@@ -76,9 +76,12 @@ typedef struct librdf_serializer_factory_s librdf_serializer_factory;
 
 /* for the memory allocation functions */
 #if defined(HAVE_DMALLOC_H) && defined(LIBRDF_MEMORY_DEBUG_DMALLOC)
-#include <dmalloc.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
 #undef HAVE_STDLIB_H
 #endif
+#include <dmalloc.h>
+#endif
 
 
 #ifdef LIBRDF_MEMORY_DEBUG
@@ -114,6 +117,12 @@ void librdf_memory_report(FILE *fh);
 #define LIBRDF_FATAL2(function, msg,arg) do {fprintf(stderr, "%s:%d:%s: fatal error: " msg, __FILE__, __LINE__ , #function, arg); abort();} while(0)
 
 
+/* Required for va_list in error handler function registrations
+ * which are in the public API
+ */
+#include <stdarg.h>
+
+
 /* these includes should be replaced with automatically pulled
  * definitions from rdf_*.h headers 
  */
