@@ -2,7 +2,7 @@
  *
  * rdf_init.h - Overall library initialisation / termination prototypes
  *
- * $Id: rdf_init.h,v 1.6 2002/05/28 22:02:30 cmdjb Exp $
+ * $Id: rdf_init.h,v 1.8 2002/08/17 18:37:43 cmdjb Exp $
  *
  * Copyright (C) 2000-2001 David Beckett - http://purl.org/net/dajobe/
  * Institute for Learning and Research Technology - http://www.ilrt.org/
@@ -33,8 +33,8 @@ struct librdf_world_s
 {
   void *error_user_data;
   void *warning_user_data;
-  void (*error_fn)(void *user_data, const char *msg, ...);
-  void (*warning_fn)(void *user_data, const char *msg, ...);
+  void (*error_fn)(void *user_data, const char *message, va_list arguments);
+  void (*warning_fn)(void *user_data, const char *message, va_list arguments);
 
   char *digest_factory_name;
   librdf_digest_factory* digest_factory;
@@ -66,8 +66,8 @@ librdf_world* librdf_new_world(void);
 void librdf_free_world(librdf_world *world);
 void librdf_world_open(librdf_world *world);
   
-void librdf_world_set_error(librdf_world* world, void *user_data, void (*error_fn)(void *user_data, const char *msg, ...));
-void librdf_world_set_warning(librdf_world* world, void *user_data, void (*warning_fn)(void *user_data, const char *msg, ...));
+void librdf_world_set_error(librdf_world* world, void *user_data, void (*error_fn)(void *user_data, const char *message, va_list arguments));
+void librdf_world_set_warning(librdf_world* world, void *user_data, void (*warning_fn)(void *user_data, const char *message, va_list arguments));
 
 void librdf_world_set_digest(librdf_world*, const char *name);
 void librdf_world_set_uris_hash(librdf_world* world, librdf_hash* uris_hash);
