@@ -2,7 +2,7 @@
  *
  * rdf_model.h - RDF Model definition
  *
- * $Id: rdf_model.h,v 1.23 2002/05/23 19:09:53 cmdjb Exp $
+ * $Id: rdf_model.h,v 1.27 2002/12/28 13:56:23 cmdjb Exp $
  *
  * Copyright (C) 2000-2001 David Beckett - http://purl.org/net/dajobe/
  * Institute for Learning and Research Technology - http://www.ilrt.org/
@@ -70,7 +70,8 @@ int librdf_model_size(librdf_model* model);
 
 /* add statements */
 int librdf_model_add(librdf_model* model, librdf_node* subject, librdf_node* predicate, librdf_node* object);
-int librdf_model_add_string_literal_statement(librdf_model* model, librdf_node* subject, librdf_node* predicate, char* string, char *xml_language, int xml_space, int is_wf_xml);
+int librdf_model_add_string_literal_statement(librdf_model* model, librdf_node* subject, librdf_node* predicate, char* string, char *xml_language, int is_wf_xml);
+int librdf_model_add_typed_literal_statement(librdf_model* model, librdf_node* subject, librdf_node* predicate, char* string, char *xml_language, librdf_uri *datatype_uri);
 int librdf_model_add_statement(librdf_model* model, librdf_statement* statement);
 int librdf_model_add_statements(librdf_model* model, librdf_stream* statement_stream);
 
@@ -113,9 +114,12 @@ int librdf_model_remove_submodel(librdf_model* model, librdf_model* sub_model);
 
 void librdf_model_print(librdf_model *model, FILE *fh);
 
-/* statement groups */
-int librdf_model_add_statements_group(librdf_model* model, librdf_uri* group_uri, librdf_stream* stream);
-int librdf_model_remove_statements_group(librdf_model* model, librdf_uri* group_uri);
+/* statement contexts */
+int librdf_model_context_add_statement(librdf_model* model, librdf_node* context, librdf_statement* statement);
+int librdf_model_context_add_statements(librdf_model* model, librdf_node* context, librdf_stream* stream);
+int librdf_model_context_remove_statement(librdf_model* model, librdf_node* context, librdf_statement* statement);
+int librdf_model_context_remove_statements(librdf_model* model, librdf_node* context);
+librdf_stream* librdf_model_context_serialize(librdf_model* model, librdf_node* context);
 
 /* query language */
 librdf_stream* librdf_model_query(librdf_model* model, librdf_query* query);
